Package: flowBin
Type: Package
Title: Combining multitube flow cytometry data by binning
Version: 1.48.0
Date: 2013-5-11
Author: Kieran O'Neill
Maintainer: Kieran O'Neill <koneill@bccrc.ca>
Description: Software to combine flow cytometry data that has been multiplexed
    into multiple tubes with common markers between them, by establishing
    common bins across tubes in terms of the common markers, then determining
    expression within each tube for each bin in terms of the tube-specific
    markers.
License: Artistic-2.0
LazyLoad: yes
Imports: class, limma, snow, BiocGenerics
Depends: methods, flowCore, flowFP, R (>= 2.10)
Suggests: parallel
biocViews: ImmunoOncology, CellBasedAssays, FlowCytometry
Collate: 'AllClasses.R' 'AllGenerics.R' 'BinnedFlowSample-accessors.R'
        'checkQNorm.R' 'flowBin.R' 'flowFPBin.R'
        'FlowSample-accessors.R' 'getBinExpr.R' 'kMeansBin.R'
        'mapClustersKNN.R' 'quantileNormalise.R' 'removeSparseBins.R'
git_url: https://git.bioconductor.org/packages/flowBin
git_branch: RELEASE_3_23
git_last_commit: e7f1786
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:10:03 UTC; biocbuild
Built: R 4.6.0; ; 2026-04-29 04:42:59 UTC; unix
