export(checkQNorm)
exportClasses(BinnedFlowSample)
exportClasses(FlowSample)
export(flowBin)
exportMethods("bin.labels<-")
exportMethods(bin.labels)
exportMethods("bin.pars<-")
exportMethods(bin.pars)
exportMethods(checkQNorm)
exportMethods("control.tubes<-")
exportMethods(control.tubes)
exportMethods(eventsInBins)
exportMethods(flowFPBin)
exportMethods(getBinExpr)
exportMethods(kMeansBin)
exportMethods(mapBinsKNN)
exportMethods("measure.pars<-")
exportMethods(measure.pars)
exportMethods("name<-")
exportMethods(name)
exportMethods(quantileNormalise)
exportMethods(removeSparseBins)
exportMethods(show)
exportMethods("tube.set<-")
exportMethods(tube.set)
import(flowFP)
importFrom(BiocGenerics,counts)
importFrom(class,knn)
importFrom(limma,normalizeQuantiles)
importFrom(snow,clusterEvalQ)
import(methods)
